@@ -4,7 +4,7 @@ import (
 	"sync"
 	"time"
 
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 )
 
 type Interface interface {
@@ -13,8 +13,14 @@ type Interface interface {
 
 type Operation string
 
-// Specific flag for summary related to uploading process.
-const Uploading Operation = "Uploading"
+const (
+	// DownloadingReport specific flag for Smart Proxy report downloading process.
+	DownloadingReport Operation = "DownloadingReport"
+	// Uploading specific flag for summary related to uploading process.
+	Uploading Operation = "Uploading"
+	// GatheringReport specific for gathering the report from the cluster
+	GatheringReport Operation = "GatheringReport"
+)
 
 type Summary struct {
 	Operation          Operation
